/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _GPXE_RDTSC_TIMER_H
#define _GPXE_RDTSC_TIMER_H

/** @file
 *
 * RDTSC timer
 *
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#ifdef TIMER_RDTSC
#define TIMER_PREFIX_rdtsc
#else
#define TIMER_PREFIX_rdtsc __rdtsc_
#endif

/**
 * RDTSC values can easily overflow an unsigned long.  We discard the
 * low-order bits in order to obtain sensibly-scaled values.
 */
#define TSC_SHIFT 8

/**
 * Get current system time in ticks
 *
 * @ret ticks		Current time, in ticks
 */
static inline __always_inline unsigned long
TIMER_INLINE ( rdtsc, currticks ) ( void ) {
	unsigned long ticks;

	__asm__ __volatile__ ( "rdtsc\n\t"
			       "shrdl %1, %%edx, %%eax\n\t"
			       : "=a" ( ticks ) : "i" ( TSC_SHIFT ) : "edx" );
	return ticks;
}

#endif /* _GPXE_RDTSC_TIMER_H */
