/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _GPXE_HMAC_H
#define _GPXE_HMAC_H

/** @file
 *
 * Keyed-Hashing for Message Authentication
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <gpxe/crypto.h>

/**
 * Update HMAC
 *
 * @v digest		Digest algorithm to use
 * @v digest_ctx	Digest context
 * @v data		Data
 * @v len		Length of data
 */
static inline void hmac_update ( struct crypto_algorithm *digest,
				 void *digest_ctx, const void *data,
				 size_t len ) {
	digest_update ( digest, digest_ctx, data, len );
}

extern void hmac_init ( struct crypto_algorithm *digest, void *digest_ctx,
			void *key, size_t *key_len );
extern void hmac_final ( struct crypto_algorithm *digest, void *digest_ctx,
			 void *key, size_t *key_len, void *hmac );

#endif /* _GPXE_HMAC_H */
