/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _GPXE_NVO_H
#define _GPXE_NVO_H

/** @file
 *
 * Non-volatile stored options
 *
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <stdint.h>
#include <gpxe/dhcpopts.h>
#include <gpxe/settings.h>

struct nvs_device;
struct refcnt;

/**
 * A fragment of a non-volatile storage device used for stored options
 */
struct nvo_fragment {
	/** Starting address of fragment within NVS device */
	unsigned int address;
	/** Length of fragment */
	size_t len;
};

/**
 * A block of non-volatile stored options
 */
struct nvo_block {
	/** Settings block */
	struct settings settings;
	/** Underlying non-volatile storage device */
	struct nvs_device *nvs;
	/** List of option-containing fragments
	 *
	 * The list is terminated by a fragment with a length of zero.
	 */
	struct nvo_fragment *fragments;
	/** Total length of option-containing fragments */
	size_t total_len;
	/** Option-containing data */
	void *data;
	/** DHCP options block */
	struct dhcp_options dhcpopts;
	/** SFC: If set, writes are not flushed back to the nvs device */
	int holdoff;
};

extern void nvo_init ( struct nvo_block *nvo, struct nvs_device *nvs,
		       struct nvo_fragment *fragments, struct refcnt *refcnt );
extern int register_nvo ( struct nvo_block *nvo, struct settings *parent,
			  void *data, size_t opts_len );
extern void unregister_nvo ( struct nvo_block *nvo );
extern void nvo_set_holdoff ( struct nvo_block *nvo, int holdoff );
extern int nvo_load ( struct nvo_block *nvo );

extern int nvo_applies ( struct settings *settings, struct setting *setting );
extern int nvo_store ( struct settings *settings, struct setting *setting,
		       const void *data, size_t len );
extern int nvo_fetch ( struct settings *settings, struct setting *setting,
		       void *data, size_t len );
extern int nvo_clear ( struct settings *settings );


#endif /* _GPXE_NVO_H */
